@@ -1,5 +1,5 @@
 # FedEx::DirectConnect
-#$Id: DirectConnect.pm,v 1.10 2003/06/06 22:27:47 jay.powers Exp $
+#$Id: DirectConnect.pm,v 1.13 2003/06/18 17:09:20 jay.powers Exp $
 # Copyright (c) 2003 Jay Powers
 # All rights reserved.
 # 
@@ -11,7 +11,7 @@ package Business::FedEx::DirectConnect; #must be in Business/FedEx
 use Business::FedEx::Constants qw($FE_RE $FE_SE $FE_TT $FE_RQ); # get all the FedEx return codes
 use LWP::UserAgent;
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 use strict;
 
@@ -70,7 +70,7 @@ sub transaction {
 			 }
 		}
 	}
-	if (!$self->{sbuf}) {		
+	if (!$self->{sbuf}) {
 		$self->errstr("Error: You must provide data to send to FedEx.");
 		return undef;
 	}
@@ -82,8 +82,8 @@ sub transaction {
 		$self->errstr("Error: You must provide a valid FedEx meter number.");
 		return undef;
 	}
-	
-	if ($self->_send())	{ # send POST to FedEx	
+
+	if ($self->_send())	{ # send POST to FedEx
 		$self->{rbuf} =~ s/\s+$//g if ($self->{rbuf} =~ /\s+$/); # get rid of the extra spaces
 		$self->_split_data();
 		# Check for Errors from FedEx
@@ -108,7 +108,7 @@ sub _send {
 	my $req = HTTP::Request->new(POST => $self->{uri}); # Create a request
 	$req->header('Host' => $self->{host}
 	,'Referer' => $self->{referer}
-	,'User-Agent' => 'Business-FedEx-DirectConnect/'.$VERSION
+	,'User-Agent' => 'Business-FedEx-DirectConnect-'.$VERSION
 	,'Accept' => "image/gif,image/jpeg,image/pjpeg,text/plain,text/html,*/*"
 	,'Content-Type' => "image/gif"
 	,'Content-Length' => $bufferLength);
@@ -209,53 +209,50 @@ Business::FedEx::DirectConnect - FedEx Ship Manager Direct Connect
 
 =head1 SYNOPSIS
 
-  use Business::FedEx::DirectConnect;
-  
-  my $t = Business::FedEx::DirectConnect->new(uri=>'https://gatewaybeta.fedex.com/GatewayDC'
-  				,acc => '' #FedEx Account Number
-  				,meter => '' #FedEx Meter Number (This is given after you subscribe to FedEx)
-  				,referer => 'Vermonster' # Name or Company
-  				,host=> 'gatewaybeta.fedex.com' #Host
-  				);
-  
-  # 2016 is the UTI for FedEx.  If you don't know what this is
-  # you need to read the FedEx Documentation.
-  # http://www.fedex.com/globaldeveloper/shipapi/
-  # The hash values are case insensitive.
-  $t->set_data(2016,
-  'customer_transaction_identifier' => 'unique1234'
-  'sender_company' => 'Vermonster LLC',
-  'sender_address_line_1' => '312 stuart st',
-  'sender_city' => 'Boston',
-  'sender_state' => 'MA',
-  'sender_postal_code' => '02134',
-  'recipient_contact_name' => 'Jay Powers',
-  'recipient_addre  _line_1' => '44 main street',
-  'recipient_city' => 'boston',
-  'recipient_state' => 'MA',
-  'recipient_postal_code' => '02116',
-  'recipient_phone_number' => '6173335555',
-  'weight_units' => 'lbs',
-  'sender_country_code' => 'US',
-  'recipient_country' => 'US',
-  'sender_phone_number' => '6175556985',
-  'future_day_shipment' => 'y',
-  'packaging_type' => '01',
-  'service_type' => '03',
-  'total_package_weight' => '1.0',
-  'label_type' => '1',
-  'label_printer_type' => '1',
-  'label_media_type' => '5',
-  'ship_date' => '20020828',
-  'customs_declared_value_currency_type' => 'USD',
-  'package_total' => 1
-  ) or die $t->errstr;
-  
-  $t->transaction() or die $t->errstr;
-  
-  print $t->lookup('tracking_number');
+        use Business::FedEx::DirectConnect;
 
-  $t->label("myLabel.png");
+        my $t = Business::FedEx::DirectConnect->new(uri=>'https://gatewaybeta.fedex.com/GatewayDC'
+                                        ,acc => '' #FedEx Account Number
+                                        ,meter => '' #FedEx Meter Number (This is given after you subscribe to FedEx)
+                                        ,referer => 'Vermonster' # Name or Company
+                                        ,host=> 'gatewaybeta.fedex.com' #Host
+                                        ,Debug => 1
+                                        );
+
+        # 2016 is the UTI for FedEx.  If you don't know what this is
+        # you need to read the FedEx Documentation.
+        # http://www.fedex.com/globaldeveloper/shipapi/
+        # The hash values are case insensitive.
+        $t->set_data(2016,
+        'sender_company' => 'Vermonster LLC',
+        'sender_address_line_1' => '312 stuart st',
+        'sender_city' => 'Boston',
+        'sender_state' => 'MA',
+        'sender_postal_code' => '02134',
+        'recipient_contact_name' => 'Jay Powers',
+        'recipient_address_line_1' => '44 Main street',
+        'recipient_city' => 'Boston',
+        'recipient_state' => 'Ma',
+        'recipient_postal_code' => '02116',
+        'recipient_phone_number' => '6173335555',
+        'weight_units' => 'LBS',
+        'sender_country_code' => 'US',
+        'recipient_country' => 'US',
+        'sender_phone_Number' => '6175556985',
+        'packaging_type' => '01',
+        'service_type' => '03',
+        'total_package_weight' => '1.0',
+        'label_type' => '1',
+        'label_printer_type' => '1',
+        'label_media_type' => '1',
+        'drop_off_type' => '1'
+        ) or die $t->errstr;
+
+        $t->transaction() or die $t->errstr;
+
+        print $t->lookup('tracking_number');
+
+        $t->label("myLabel.png");
 
 
 =head1 DESCRIPTION
